@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2018 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,10 @@
  * MA 02110-1301, USA.
  */
 
-#include <QtCore/QTextStream>
+#include <QTextStream>
 
 #include <U2Core/AppContext.h>
+#include <U2Core/Counter.h>
 #include <U2Core/GUrl.h>
 #include <U2Core/L10n.h>
 #include <U2Core/Log.h>
@@ -123,7 +124,7 @@ QString HRSchemaSerializer::valueString(const QString & s, bool quoteEmpty) {
     if( str.contains(QRegExp("\\s") ) || str.contains(Constants::SEMICOLON) ||
         str.contains(Constants::EQUALS_SIGN) || str.contains(Constants::DATAFLOW_SIGN) ||
         str.contains(Constants::BLOCK_START) || str.contains(Constants::BLOCK_END) ||
-        str.contains(OldConstants::MARKER_START) ||
+        str.contains(Constants::SINGLE_QUOTE) || str.contains(OldConstants::MARKER_START) ||
         (str.isEmpty() && quoteEmpty)) {
         return quotedString(str);
     } else {
@@ -327,10 +328,10 @@ void HRSchemaSerializer::deprecatedUrlAttribute(Actor *proc, const QString &urls
     }
 }
 
-QList<Dataset> HRSchemaSerializer::parseUrlAttribute(const QString attrId, QList<StringPair> &blockPairs) {
+QList<Dataset> HRSchemaSerializer::parseUrlAttribute(const QString attrId, QList<StrStrPair> &blockPairs) {
     QList<Dataset> sets;
     QStringList setBlocks;
-    foreach (const StringPair &pair, blockPairs) {
+    foreach (const StrStrPair &pair, blockPairs) {
         if (attrId == pair.first) {
             setBlocks << pair.second;
             blockPairs.removeOne(pair);
@@ -361,7 +362,7 @@ QList<Dataset> HRSchemaSerializer::parseUrlAttribute(const QString attrId, QList
             if (name.isEmpty()) {
                 throw ReadFailed(tr("Url definition does not contain dataset name"));
             }
-        } catch (ReadFailed ex) {
+        } catch (const ReadFailed &ex) {
             foreach (URLContainer *url, urls) {
                 delete url;
             }
@@ -482,7 +483,7 @@ URLContainer * HRSchemaSerializer::parseDirectoryUrl(Tokenizer &tokenizer) {
 
         return new DirUrlContainer(path, incFilter, excFilter, recursive);
     } else {
-        throw ReadFailed(tr("Directory url definition: '%1' or '%2' are expected, '%3' is found")
+        throw ReadFailed(tr("folder url definition: '%1' or '%2' are expected, '%3' is found")
             .arg(Constants::BLOCK_START).arg(Constants::EQUALS_SIGN).arg(sign));
     }
 }
@@ -539,7 +540,7 @@ Actor* HRSchemaSerializer::parseElementsDefinition(Tokenizer & tokenizer, const
             parseGrouperOutSlots(proc, pairs.blockPairs.values(key), key);
         } else if (MARKER_GROUP == a->getGroup()) {
             parseMarkers(proc, pairs.blockPairs.values(key), key);
-        } else if (NULL != dynamic_cast<URLAttribute*>(a)) {
+        } else if (a->getAttributeType()->getId() == BaseTypes::URL_DATASETS_TYPE()->getId()) {
             QList<Dataset> sets = parseUrlAttribute(a->getId(), pairs.blockPairsList);
             a->setAttributeValue(qVariantFromValue< QList<Dataset> >(sets));
         } else {
@@ -547,14 +548,27 @@ Actor* HRSchemaSerializer::parseElementsDefinition(Tokenizer & tokenizer, const
         }
     }
 
+    bool workflowContainsInvalidFormatIds = false;
     foreach( const QString & key, pairs.equalPairs.keys() ) {
         Attribute *attr = proc->getParameter(key);
+        QString value = pairs.equalPairs.value(key);
+
+        if (key == BaseAttributes::DOCUMENT_FORMAT_ATTRIBUTE().getId()) {
+            if (BaseDocumentFormats::isInvalidId(value)) {
+                workflowContainsInvalidFormatIds = true;
+                value = BaseDocumentFormats::toValidId(value);
+            }
+        }
+
         if (NULL != attr) {
-           attr->setAttributeValue(getAttrValue(proc, key, pairs.equalPairs.value(key)));
+           attr->setAttributeValue(getAttrValue(proc, key, value));
         } else {
             coreLog.details(tr("Unexpected actor attribute: %1").arg(key));
         }
     }
+    if (workflowContainsInvalidFormatIds) {
+        GCOUNTER(cvar, tvar, "Invalid format IDs: an element was saved with 1.26.0");
+    }
 
     foreach (const QString &valDef, pairs.blockPairs.values(Constants::VALIDATOR)) {
         U2OpStatus2Log os;
@@ -563,7 +577,7 @@ Actor* HRSchemaSerializer::parseElementsDefinition(Tokenizer & tokenizer, const
             proc->addCustomValidator(desc);
         }
     }
-    proc->updatePortsAvailability();
+    proc->updateItemsAvailability();
 
     return proc;
 }
@@ -772,7 +786,7 @@ QMap<ActorId, QVariantMap> HRSchemaSerializer::parseIteration(Tokenizer & tokeni
                 cfg[actorId][attrId] =
                     getAttrValue(actorMap[actorName], attrId, pairs.equalPairs[attrId]);
             }
-            if (NULL == dynamic_cast<URLAttribute*>(attr)) {
+            if (attr->getAttributeType()->getId() != BaseTypes::URL_DATASETS_TYPE()->getId()) {
                 continue;
             }
             QList<Dataset> sets = parseUrlAttribute(attrId, pairs.blockPairsList);
@@ -1220,7 +1234,7 @@ void HRSchemaSerializer::addEmptyValsToBindings(const QList<Actor*> & procs) {
     foreach(Actor * actor, procs) {
         foreach(Port * p, actor->getInputPorts()) {
             IntegralBusPort * port = qobject_cast<IntegralBusPort*>(p);
-            QStrStrMap busMap = port->getParameter(IntegralBusPort::BUS_MAP_ATTR_ID)->getAttributeValueWithoutScript<QStrStrMap>();
+            StrStrMap busMap = port->getParameter(IntegralBusPort::BUS_MAP_ATTR_ID)->getAttributeValueWithoutScript<StrStrMap>();
             DataTypePtr t = port->Port::getType();
             assert(t->isMap());
             QMap<Descriptor, DataTypePtr> typeMap = t->getDatatypesMap();
@@ -1273,13 +1287,13 @@ void HRSchemaSerializer::postProcessing(Schema *schema) {
         CHECK(proto != NULL, );
         foreach (Attribute* attr, proto->getAttributes()) {
             CHECK(attr != NULL, );
-            foreach (const PortRelationDescriptor& pd, attr->getPortRelations()) {
-                Port* p = a->getPort(pd.portId);
+            foreach (PortRelationDescriptor* pd, attr->getPortRelations()) {
+                Port* p = a->getPort(pd->getPortId());
                 CHECK(p != NULL, );
                 CHECK(a->hasParameter(attr->getId()), );
                 QVariant value = a->getParameter(attr->getId())->getAttributePureValue();
-                if (!p->getLinks().isEmpty() && !pd.valuesWithEnabledPort.contains(value)) {
-                    a->setParameter(attr->getId(), pd.valuesWithEnabledPort.first());
+                if (!p->getLinks().isEmpty() && !pd->isPortEnabled(value)) {
+                    a->setParameter(attr->getId(), pd->getValuesWithEnabledPort().first());
                 }
             }
         }
@@ -1594,11 +1608,11 @@ static QString elementsDefinitionBlock(Actor * actor, bool copyMode) {
         } else if (MARKER_GROUP == attribute->getGroup()) {
             res += HRSchemaSerializer::markersDefinition(attribute);
         } else {
-            if (attribute->getId() == BaseAttributes::URL_IN_ATTRIBUTE().getId()) {
+            if (attribute->getAttributeType() == BaseTypes::URL_DATASETS_TYPE()) {
                 QVariant v = attribute->getAttributePureValue();
                 if (v.canConvert< QList<Dataset> >()) {
                     QList<Dataset> sets = v.value< QList<Dataset> >();
-                    res += inUrlDefinitionBlocks(BaseAttributes::URL_IN_ATTRIBUTE().getId(), sets, 2);
+                    res += inUrlDefinitionBlocks(attribute->getId(), sets, 2);
                     continue;
                 }
             }
@@ -1616,8 +1630,27 @@ static QString elementsDefinitionBlock(Actor * actor, bool copyMode) {
                 continue;
             }
             QVariant value = attribute->getAttributePureValue();
-            assert(value.isNull() || value.canConvert<QString>());
-            res += HRSchemaSerializer::makeEqualsPair(attributeId, value.toString(), 2, true);
+
+#ifdef _DEBUG
+            const bool valueIsNull = value.isNull();
+            const bool valueCanConvertToString = value.canConvert<QString>();
+            const bool valueCanConvertToStringList = value.canConvert<QStringList>();
+            const bool valueCanConvertToMap = value.canConvert<QMap<QString, QVariant> >();
+            assert(valueIsNull ||
+                   valueCanConvertToString ||
+                   valueCanConvertToStringList ||
+                   valueCanConvertToMap);
+#endif
+
+            QString valueString;
+            if (attribute->getAttributeType() == BaseTypes::STRING_LIST_TYPE()) {
+                valueString = StrPackUtils::packStringList(value.toStringList(), StrPackUtils::SingleQuotes);
+            } else if (attribute->getAttributeType() == BaseTypes::MAP_TYPE()) {
+                valueString = StrPackUtils::packMap(value.toMap(), StrPackUtils::SingleQuotes);
+            } else {
+                valueString = value.toString();
+            }
+            res += HRSchemaSerializer::makeEqualsPair(attributeId, valueString, 2, true);
         }
     }
 
@@ -1731,7 +1764,7 @@ QString HRSchemaSerializer::dataflowDefinition(const QList<Actor*> & procs, cons
     QString res;
     foreach(Actor * actor, procs) {
         foreach(Port * inputPort, actor->getEnabledInputPorts()) {
-            QStrStrMap busMap = inputPort->getParameter(IntegralBusPort::BUS_MAP_ATTR_ID)->getAttributeValueWithoutScript<QStrStrMap>();
+            StrStrMap busMap = inputPort->getParameter(IntegralBusPort::BUS_MAP_ATTR_ID)->getAttributeValueWithoutScript<StrStrMap>();
             IntegralBusPort *busPort = qobject_cast<IntegralBusPort*>(inputPort);
 
             foreach( const QString & key, busMap.keys() ) {
